@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 """
-    :copyright: Copyright 2013 by Łukasz Mierzwa
+    :copyright: Copyright 2013-2014 by Łukasz Mierzwa
     :contact: l.mierzwa@gmail.com
 """
 
@@ -16,6 +16,7 @@ import pytest
 
 from upaas.storage.local import LocalStorage
 from upaas.storage.exceptions import FileNotFound
+from upaas.storage.utils import find_storage_handler
 from upaas.config.base import ConfigurationError
 
 
@@ -31,6 +32,16 @@ def storage(request):
     return storage
 
 
+def test_find_storage():
+    assert find_storage_handler(
+        'upaas.storage.local.LocalStorage', settings={'dir': '/'}) is not None
+
+
+def test_find_storage_invalid():
+    with pytest.raises(ConfigurationError):
+        find_storage_handler('upaas.storage.local.LocalStorage')
+
+
 def test_valid_settings(storage):
     assert storage.settings.dir is not None
 
