@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 """
-    :copyright: Copyright 2013 by Łukasz Mierzwa
+    :copyright: Copyright 2013-2014 by Łukasz Mierzwa
     :contact: l.mierzwa@gmail.com
 """
 
@@ -17,6 +17,7 @@ from pymongo import MongoClient
 
 from upaas.storage.mongodb import MongoDBStorage
 from upaas.storage.exceptions import FileNotFound
+from upaas.storage.utils import find_storage_handler
 from upaas.config.base import ConfigurationError
 
 
@@ -33,6 +34,11 @@ def storage(request):
     return storage
 
 
+def test_find_storage():
+    assert find_storage_handler(
+        'upaas.storage.mongodb.MongoDBStorage') is not None
+
+
 def test_valid_settings(storage):
     assert storage.settings.host == "localhost"
     assert storage.settings.port == 27017
@@ -90,5 +96,5 @@ def test_size_not_empty(storage, empty_file):
 def test_mtime(storage, empty_file):
     storage.put(empty_file, "mtime.check")
     assert isinstance(storage.mtime("mtime.check"), datetime.datetime)
-    #FIXME basic check to verify if timestamp is from the past
+    # FIXME basic check to verify if timestamp is from the past
     assert storage.mtime("mtime.check") < datetime.datetime.now()
