@@ -9,7 +9,6 @@ from __future__ import unicode_literals
 
 import os
 import tempfile
-import shutil
 import datetime
 import logging
 
@@ -43,8 +42,6 @@ class BuildResult:
         # selected interpreter version
         self.interpreter_version = None
 
-        # class of the storage this package was uploaded to
-        self.storage = None
         # package filename
         self.filename = None
         # package checksum
@@ -308,7 +305,7 @@ class Builder(object):
 
         # directory is encoded into string to prevent unicode errors
         directory = tempfile.mkdtemp(dir=self.config.paths.workdir,
-                                     prefix="upaas_package_").encode("utf-8")
+                                     prefix="upaas_package_")
         workdir = os.path.join(directory, "workdir")
         chroot_homedir = self.config.apps.home
         os.mkdir(workdir, 0o755)
@@ -425,7 +422,6 @@ class Builder(object):
         kill_and_remove_dir(directory)
 
         result.progress = 100
-        result.storage = self.storage.__class__.__name__
         result.filename = checksum
         result.checksum = checksum
         yield result
@@ -642,7 +638,7 @@ class Builder(object):
 
         # directory is encoded into string to prevent unicode errors
         directory = tempfile.mkdtemp(dir=self.config.paths.workdir,
-                                     prefix="upaas_bootstrap_").encode("utf-8")
+                                     prefix="upaas_bootstrap_")
         log.debug("Created temporary directory for bootstrap at "
                   "'%s'" % directory)
 
