@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 """
-    :copyright: Copyright 2013 by Łukasz Mierzwa
+    :copyright: Copyright 2013-2014 by Łukasz Mierzwa
     :contact: l.mierzwa@gmail.com
 """
 
@@ -64,7 +64,7 @@ class ConfigEntry(object):
 
     def __init__(self, required=False, default=None):
         self.required = required
-        if not default is None:
+        if default is not None:
             self.default = default
 
     @staticmethod
@@ -306,7 +306,8 @@ class Config(object):
         Parse and validate single configuration entry using schema.
         """
         log.debug("Parsing configuration entry '%s'" % self.child_name(name))
-        if entry_schema.required and value is None:
+        if entry_schema.required and value is None and \
+                entry_schema.default is None:
             self.fail("Missing required configuration entry: "
                       "%s" % self.child_name(name))
         log.debug("Cleaning configuration entry '%s'" % self.child_name(name))
