@@ -28,5 +28,5 @@ def distro_arch():
 
 def distro_image_filename():
     # FIXME tar.gz is hardcoded?
-    return "%s-%s-%s.tar.gz" % (distro_name(), distro_version(),
-                                distro_arch())
+    path = "%s-%s-%s.tar.gz" % (distro_name(), distro_version(), distro_arch())
+    return path.replace('/', '-')
